@@ -12,7 +12,7 @@ use Specio::Library::String;
 
 use Moo;
 
-our $VERSION = '0.78';
+our $VERSION = '0.79';
 
 has base_sig => (
     is      => 'ro',
@@ -141,7 +141,7 @@ Code::TidyAll::CacheModel - Caching model for Code::TidyAll
 
 =head1 VERSION
 
-version 0.78
+version 0.79
 
 =head1 SYNOPSIS
 
@@ -254,15 +254,11 @@ Attempts to remove the value from the cache.
 
 =head1 SUPPORT
 
-Bugs may be submitted at
-L<https://github.com/houseabsolute/perl-code-tidyall/issues>.
-
-I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
+Bugs may be submitted at L<https://github.com/houseabsolute/perl-code-tidyall/issues>.
 
 =head1 SOURCE
 
-The source code repository for Code-TidyAll can be found at
-L<https://github.com/houseabsolute/perl-code-tidyall>.
+The source code repository for Code-TidyAll can be found at L<https://github.com/houseabsolute/perl-code-tidyall>.
 
 =head1 AUTHORS
 
@@ -280,12 +276,12 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 - 2020 by Jonathan Swartz.
+This software is copyright (c) 2011 - 2021 by Jonathan Swartz.
 
-This is free software; you can redistribute it and/or modify it under the same
-terms as the Perl 5 programming language system itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
-The full text of the license can be found in the F<LICENSE> file included with
-this distribution.
+The full text of the license can be found in the
+F<LICENSE> file included with this distribution.
 
 =cut
