@@ -5,7 +5,7 @@ use warnings;
 
 use base qw(Config::INI::Reader);
 
-our $VERSION = '0.78';
+our $VERSION = '0.79';
 
 my %multi_value = map { $_ => 1 } qw( ignore inc ok_exit_codes select shebang );
 
@@ -36,24 +36,19 @@ __END__
 
 =head1 NAME
 
-Code::TidyAll::Config::INI::Reader - A L<Config::INI::Reader> subclass which
-can handle a key appearing more than once
+Code::TidyAll::Config::INI::Reader - A L<Config::INI::Reader> subclass which can handle a key appearing more than once
 
 =head1 VERSION
 
-version 0.78
+version 0.79
 
 =head1 SUPPORT
 
-Bugs may be submitted at
-L<https://github.com/houseabsolute/perl-code-tidyall/issues>.
-
-I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
+Bugs may be submitted at L<https://github.com/houseabsolute/perl-code-tidyall/issues>.
 
 =head1 SOURCE
 
-The source code repository for Code-TidyAll can be found at
-L<https://github.com/houseabsolute/perl-code-tidyall>.
+The source code repository for Code-TidyAll can be found at L<https://github.com/houseabsolute/perl-code-tidyall>.
 
 =head1 AUTHORS
 
@@ -71,12 +66,12 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 - 2020 by Jonathan Swartz.
+This software is copyright (c) 2011 - 2021 by Jonathan Swartz.
 
-This is free software; you can redistribute it and/or modify it under the same
-terms as the Perl 5 programming language system itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
-The full text of the license can be found in the F<LICENSE> file included with
-this distribution.
+The full text of the license can be found in the
+F<LICENSE> file included with this distribution.
 
 =cut
