@@ -8,7 +8,7 @@ use Specio::Library::Builtins;
 
 use Moo;
 
-our $VERSION = '0.75';
+our $VERSION = '0.79';
 
 extends 'Code::TidyAll::Plugin';
 
@@ -46,12 +46,11 @@ __END__
 
 =head1 NAME
 
-Code::TidyAll::Plugin::JSON - Use the JSON::MaybeXS module to tidy JSON
-documents with tidyall
+Code::TidyAll::Plugin::JSON - Use the JSON::MaybeXS module to tidy JSON documents with tidyall
 
 =head1 VERSION
 
-version 0.75
+version 0.79
 
 =head1 SYNOPSIS
 
@@ -76,15 +75,11 @@ Escape non-ASCII characters. The output file will be valid ASCII.
 
 =head1 SUPPORT
 
-Bugs may be submitted at
-L<https://github.com/houseabsolute/perl-code-tidyall/issues>.
-
-I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
+Bugs may be submitted at L<https://github.com/houseabsolute/perl-code-tidyall/issues>.
 
 =head1 SOURCE
 
-The source code repository for Code-TidyAll can be found at
-L<https://github.com/houseabsolute/perl-code-tidyall>.
+The source code repository for Code-TidyAll can be found at L<https://github.com/houseabsolute/perl-code-tidyall>.
 
 =head1 AUTHORS
 
@@ -102,12 +97,12 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 - 2019 by Jonathan Swartz.
+This software is copyright (c) 2011 - 2021 by Jonathan Swartz.
 
-This is free software; you can redistribute it and/or modify it under the same
-terms as the Perl 5 programming language system itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
-The full text of the license can be found in the F<LICENSE> file included with
-this distribution.
+The full text of the license can be found in the
+F<LICENSE> file included with this distribution.
 
 =cut
