@@ -4,12 +4,13 @@ use strict;
 use warnings;
 
 use Specio::Declare;
+use Specio::Library::Builtins;
 use Specio::Library::Path::Tiny;
 use Specio::Library::String;
 
 use Moo;
 
-our $VERSION = '0.78';
+our $VERSION = '0.79';
 
 has error => (
     is  => 'ro',
@@ -18,12 +19,12 @@ has error => (
 
 has new_contents => (
     is  => 'ro',
-    isa => t('NonEmptyStr'),
+    isa => t('Str'),
 );
 
 has orig_contents => (
     is  => 'ro',
-    isa => t('NonEmptyStr'),
+    isa => t('Str'),
 );
 
 has path => (
@@ -54,7 +55,7 @@ Code::TidyAll::Result - Result returned from processing a file/source
 
 =head1 VERSION
 
-version 0.78
+version 0.79
 
 =head1 SYNOPSIS
 
@@ -115,15 +116,11 @@ Returns true iff state is not 'error'
 
 =head1 SUPPORT
 
-Bugs may be submitted at
-L<https://github.com/houseabsolute/perl-code-tidyall/issues>.
-
-I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
+Bugs may be submitted at L<https://github.com/houseabsolute/perl-code-tidyall/issues>.
 
 =head1 SOURCE
 
-The source code repository for Code-TidyAll can be found at
-L<https://github.com/houseabsolute/perl-code-tidyall>.
+The source code repository for Code-TidyAll can be found at L<https://github.com/houseabsolute/perl-code-tidyall>.
 
 =head1 AUTHORS
 
@@ -141,12 +138,12 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 - 2020 by Jonathan Swartz.
+This software is copyright (c) 2011 - 2021 by Jonathan Swartz.
 
-This is free software; you can redistribute it and/or modify it under the same
-terms as the Perl 5 programming language system itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
-The full text of the license can be found in the F<LICENSE> file included with
-this distribution.
+The full text of the license can be found in the
+F<LICENSE> file included with this distribution.
 
 =cut
