@@ -13,9 +13,9 @@ use Moo::Role;
 
 with 'Code::TidyAll::Role::RunsCommand';
 
-our $VERSION = '0.78';
+our $VERSION = '0.79';
 
-has '+cmd' => (
+has 'cmd' => (
     is       => 'ro',
     required => 1,
 );
@@ -49,12 +49,11 @@ __END__
 
 =head1 NAME
 
-Code::TidyAll::Role::GenericExecutable - A role for plugins which allow you to
-use any executable as a transformer or validator
+Code::TidyAll::Role::GenericExecutable - A role for plugins which allow you to use any executable as a transformer or validator
 
 =head1 VERSION
 
-version 0.78
+version 0.79
 
 =head1 SYNOPSIS
 
@@ -86,15 +85,11 @@ default, the file is simply passed as the last argument to the command.
 
 =head1 SUPPORT
 
-Bugs may be submitted at
-L<https://github.com/houseabsolute/perl-code-tidyall/issues>.
-
-I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
+Bugs may be submitted at L<https://github.com/houseabsolute/perl-code-tidyall/issues>.
 
 =head1 SOURCE
 
-The source code repository for Code-TidyAll can be found at
-L<https://github.com/houseabsolute/perl-code-tidyall>.
+The source code repository for Code-TidyAll can be found at L<https://github.com/houseabsolute/perl-code-tidyall>.
 
 =head1 AUTHORS
 
@@ -112,12 +107,12 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 - 2020 by Jonathan Swartz.
+This software is copyright (c) 2011 - 2021 by Jonathan Swartz.
 
-This is free software; you can redistribute it and/or modify it under the same
-terms as the Perl 5 programming language system itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
-The full text of the license can be found in the F<LICENSE> file included with
-this distribution.
+The full text of the license can be found in the
+F<LICENSE> file included with this distribution.
 
 =cut
