@@ -12,7 +12,7 @@ use Try::Tiny;
 
 use Moo::Role;
 
-our $VERSION = '0.75';
+our $VERSION = '0.79';
 
 has ok_exit_codes => (
     is      => 'ro',
@@ -42,7 +42,7 @@ sub _run_or_die {
     }
     catch {
         die sprintf(
-            "%s failed\n    %s",
+            "Running [%s] failed\n    %s",
             ( join q{ }, @cmd ),
             $_,
         );
@@ -70,12 +70,11 @@ __END__
 
 =head1 NAME
 
-Code::TidyAll::Role::RunsCommand - A role for plugins which run external
-commands
+Code::TidyAll::Role::RunsCommand - A role for plugins which run external commands
 
 =head1 VERSION
 
-version 0.75
+version 0.79
 
 =head1 SYNOPSIS
 
@@ -129,15 +128,11 @@ non-0 when they encounter validation/tidying issues.
 
 =head1 SUPPORT
 
-Bugs may be submitted at
-L<https://github.com/houseabsolute/perl-code-tidyall/issues>.
-
-I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
+Bugs may be submitted at L<https://github.com/houseabsolute/perl-code-tidyall/issues>.
 
 =head1 SOURCE
 
-The source code repository for Code-TidyAll can be found at
-L<https://github.com/houseabsolute/perl-code-tidyall>.
+The source code repository for Code-TidyAll can be found at L<https://github.com/houseabsolute/perl-code-tidyall>.
 
 =head1 AUTHORS
 
@@ -155,12 +150,12 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 - 2019 by Jonathan Swartz.
+This software is copyright (c) 2011 - 2021 by Jonathan Swartz.
 
-This is free software; you can redistribute it and/or modify it under the same
-terms as the Perl 5 programming language system itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
-The full text of the license can be found in the F<LICENSE> file included with
-this distribution.
+The full text of the license can be found in the
+F<LICENSE> file included with this distribution.
 
 =cut
