@@ -8,7 +8,7 @@ use IPC::System::Simple qw(capturex);
 
 use Exporter qw(import);
 
-our $VERSION = '0.75';
+our $VERSION = '0.79';
 
 our @EXPORT_OK = qw(svn_uncommitted_files);
 
@@ -16,8 +16,8 @@ sub svn_uncommitted_files {
     my ($dir) = @_;
 
     $dir = realpath($dir);
-    my $output = capturex( 'svn', 'status', $dir );
-    my @lines  = grep {/^[AM]/} split( "\n", $output );
+    my $output  = capturex( 'svn', 'status', $dir );
+    my @lines   = grep {/^[AM]/} split( "\n", $output );
     my (@files) = grep {-f} ( $output =~ m{^[AM]\s+(.*)$}gm );
     return @files;
 }
@@ -38,19 +38,15 @@ Code::TidyAll::SVN::Util - Utility functions for SVN hooks
 
 =head1 VERSION
 
-version 0.75
+version 0.79
 
 =head1 SUPPORT
 
-Bugs may be submitted at
-L<https://github.com/houseabsolute/perl-code-tidyall/issues>.
-
-I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
+Bugs may be submitted at L<https://github.com/houseabsolute/perl-code-tidyall/issues>.
 
 =head1 SOURCE
 
-The source code repository for Code-TidyAll can be found at
-L<https://github.com/houseabsolute/perl-code-tidyall>.
+The source code repository for Code-TidyAll can be found at L<https://github.com/houseabsolute/perl-code-tidyall>.
 
 =head1 AUTHORS
 
@@ -68,12 +64,12 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 - 2019 by Jonathan Swartz.
+This software is copyright (c) 2011 - 2021 by Jonathan Swartz.
 
-This is free software; you can redistribute it and/or modify it under the same
-terms as the Perl 5 programming language system itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
-The full text of the license can be found in the F<LICENSE> file included with
-this distribution.
+The full text of the license can be found in the
+F<LICENSE> file included with this distribution.
 
 =cut
