@@ -5,7 +5,7 @@ package Code::TidyAll::Util::Zglob;
 use strict;
 use warnings;
 
-our $VERSION = '0.78';
+our $VERSION = '0.79';
 
 use Exporter qw(import);
 
@@ -60,20 +60,20 @@ sub zglob_to_regex_string {
             $regex .= "\\$_";
         }
         elsif ( $_ eq "\cZ" ) {    # handle **/ - if escaping, only escape first *
-            $regex .=
-                $escaping
+            $regex
+                .= $escaping
                 ? ( "\\*" . ( $strict_wildcard_slash ? "[^/]*" : ".*" ) . "/" )
                 : ".*";
         }
         elsif ( $_ eq '*' ) {
-            $regex .=
-                  $escaping              ? "\\*"
+            $regex
+                .= $escaping             ? "\\*"
                 : $strict_wildcard_slash ? "[^/]*"
                 :                          ".*";
         }
         elsif ( $_ eq '?' ) {
-            $regex .=
-                  $escaping              ? "\\?"
+            $regex
+                .= $escaping             ? "\\?"
                 : $strict_wildcard_slash ? "[^/]"
                 :                          ".";
         }
@@ -125,19 +125,15 @@ Code::TidyAll::Util::Zglob - Test::Glob hacked up to support "**/*"
 
 =head1 VERSION
 
-version 0.78
+version 0.79
 
 =head1 SUPPORT
 
-Bugs may be submitted at
-L<https://github.com/houseabsolute/perl-code-tidyall/issues>.
-
-I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
+Bugs may be submitted at L<https://github.com/houseabsolute/perl-code-tidyall/issues>.
 
 =head1 SOURCE
 
-The source code repository for Code-TidyAll can be found at
-L<https://github.com/houseabsolute/perl-code-tidyall>.
+The source code repository for Code-TidyAll can be found at L<https://github.com/houseabsolute/perl-code-tidyall>.
 
 =head1 AUTHORS
 
@@ -155,12 +151,12 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 - 2020 by Jonathan Swartz.
+This software is copyright (c) 2011 - 2021 by Jonathan Swartz.
 
-This is free software; you can redistribute it and/or modify it under the same
-terms as the Perl 5 programming language system itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
-The full text of the license can be found in the F<LICENSE> file included with
-this distribution.
+The full text of the license can be found in the
+F<LICENSE> file included with this distribution.
 
 =cut
